@@ -8,7 +8,14 @@ import funcy
 
 from langkit import names
 from langkit.compiled_types import (
-    ASTNodeType, AbstractNodeData, EntityType, Field, resolve_type
+    ASTNodeType,
+    AbstractNodeData,
+    BaseField,
+    BaseStructType,
+    EntityType,
+    Field,
+    NodeBuilderType,
+    resolve_type,
 )
 from langkit.diagnostics import (Severity, check_source_language,
                                  diagnostic_context, error)
@@ -263,9 +270,6 @@ class New(AbstractExpression):
             self.assocs = {field_or_lookup(field): expr
                            for field, expr in assocs.items()}
 
-            for f in self.assocs:
-                f.set_synthetized()
-
             super().__init__(
                 result_var_name or 'New_Struct',
                 abstract_expr=abstract_expr
@@ -368,6 +372,111 @@ class New(AbstractExpression):
             f' ({self.struct_type.dsl_name})'
         )
 
+    @staticmethod
+    def construct_fields(
+        struct_type: BaseStructType,
+        field_values: dict[str, AbstractExpression],
+        for_node_builder: bool = False,
+    ) -> dict[BaseField, ResolvedExpression]:
+        """
+        Helper to lower fields in a struct/node constructor.
+
+        :param struct_type: Struct/node type for which we construct fields.
+        :param field_values: Mapping from field DSL name to associated field
+            initialization expression.
+        :param for_node_builder: Whether we are in the context of node
+            builders: parse field values are expected to be node builders.
+        :return: A mapping from fields to initialize to the corresponding
+            constructed initialization expression.
+        """
+        # Create a dict of field names to fields in the struct type, and
+        # another dict for default values.
+        required_fields = struct_type.required_fields_in_exprs
+        default_valued_fields = {
+            n: (f, f.abstract_default_value)
+            for n, f in required_fields.items()
+            if f.abstract_default_value is not None
+        }
+
+        # Make sure the provided set of fields matches the one the struct needs
+
+        def error_if_not_empty(name_set: set[str], message: str):
+            if name_set:
+                names_str = ", ".join(sorted(name_set))
+                error(f"{message}: {names_str}")
+
+        error_if_not_empty(
+            set(required_fields)
+            - set(field_values)
+            - set(default_valued_fields),
+            f"Values are missing for {struct_type.dsl_name} fields",
+        )
+        error_if_not_empty(
+            set(field_values.keys()) - set(required_fields),
+            f"Extraneous fields for {struct_type.dsl_name}",
+        )
+
+        # At this stage, we know that the user provided all required fields,
+        # and no spurious fields. Construct expressions for field values.
+        result = {
+            required_fields[name]: construct(expr)
+            for name, expr in field_values.items()
+        }
+
+        # Add default values for missing fields. Note that we construct their
+        # abstract expressions on purpose: even though a resolved expression is
+        # already present in field.default_value, reusing ResolvedExpression
+        # nodes in multiple expressions is forbidden. Constructing a new each
+        # time avoids this problem.
+        for name, (field, default_value) in default_valued_fields.items():
+            if field not in result:
+                result[field] = construct_compile_time_known(default_value)
+
+        # Then check that the type of these expressions match field types
+        for field, expr in result.items():
+            expected_type = field.type
+            actual_type = expr.type
+            actual_node_type: ASTNodeType
+
+            # If we are creating a node builder, expect node builders to
+            # initialize parse fields.
+            if for_node_builder and isinstance(field, Field):
+                assert isinstance(expected_type, ASTNodeType)
+                expected_type = expected_type.builder_type
+
+            check_source_language(
+                actual_type.matches(expected_type),
+                f"Wrong type for field {field.qualname}: expected"
+                f" {expected_type.dsl_name}, got {actual_type.dsl_name}"
+            )
+
+            if for_node_builder and isinstance(field, Field):
+                assert isinstance(actual_type, NodeBuilderType)
+                actual_node_type = actual_type.node_type
+            elif isinstance(field, Field):
+                assert isinstance(actual_type, ASTNodeType)
+                actual_node_type = actual_type
+
+            # Annotate parsing/synthetic fields with precise type information
+            if isinstance(field, Field):
+                field.types_from_synthesis.include(actual_node_type)
+
+            # Make sure we downcast input values so that they fit in the fields
+            if (
+                (
+                    isinstance(expected_type, ASTNodeType)
+                    or isinstance(expected_type, EntityType)
+                )
+                and actual_type != expected_type
+            ):
+                result[field] = Cast.Expr(expr, expected_type)
+
+            # Also mark parse fields as synthetized
+            if isinstance(field, Field):
+                field.set_synthetized()
+
+        return result
+
     def construct(self):
         """
         :rtype: StructExpr
@@ -384,66 +493,9 @@ class New(AbstractExpression):
                 ' properties or lazy fields'
             )
 
-        # Make sure the provided set of fields matches the one the struct
-        # needs.
-        def error_if_not_empty(name_set, message):
-            check_source_language(not name_set, ('{}: {}'.format(
-                message, ', '.join(name for name in name_set)
-            )))
-
-        # Create a dict of field names to fields in the struct type
-
-        required_fields = self.struct_type.required_fields_in_exprs
-        default_valued_fields = {n: f
-                                 for n, f in required_fields.items()
-                                 if f.default_value}
-
-        error_if_not_empty(
-            set(required_fields)
-            - set(self.field_values.keys())
-            - set(default_valued_fields),
-            'Values are missing for {} fields'.format(
-                self.struct_type.dsl_name
-            )
+        field_values = self.construct_fields(
+            self.struct_type, self.field_values
         )
-        error_if_not_empty(
-            set(self.field_values.keys()) - set(required_fields),
-            'Extraneous fields for {}'.format(self.struct_type.dsl_name)
-        )
-
-        # At this stage, we know that the user has only provided fields that
-        # are valid for the struct type. First, construct expression for field
-        # values.
-        field_values = {required_fields[name]: construct(expr)
-                        for name, expr in self.field_values.items()}
-
-        # Add default values for missing fields. Note that we construct their
-        # abstract expressions on purpose: even though a resolved expression is
-        # already present in field.default_value, reusing ResolvedExpression
-        # nodes in multiple expressions is forbidden. Constructing a new each
-        # time avoids this problem.
-        for name, field in default_valued_fields.items():
-            if field not in field_values:
-                field_values[field] = construct_compile_time_known(
-                    field.abstract_default_value
-                )
-
-        # Then check that the type of these expressions match field types
-        for field, expr in field_values.items():
-            check_source_language(
-                expr.type.matches(field.type),
-                f"Wrong type for field {field.qualname}:"
-                f" expected {field.type.dsl_name}, got {expr.type.dsl_name}"
-            )
-
-            # Annotate parsing/synthetic fields with precise type information
-            if isinstance(field, Field):
-                field.types_from_synthesis.include(expr.type)
-
-            # Make sure we downcast input values so that they fit in the
-            # fields.
-            if field.type != expr.type:
-                field_values[field] = Cast.Expr(expr, field.type)
 
         expr_cls = (New.NodeExpr
                     if self.struct_type.is_ast_node else
@@ -466,8 +518,6 @@ class FieldAccess(AbstractExpression):
         Holder for arguments to pass to a property.
         """
 
-        _traverse_in_prepare = True
-
         def __init__(self,
                      args: Sequence[AbstractExpression],
                      kwargs: Dict[str, AbstractExpression]):
@@ -475,7 +525,7 @@ class FieldAccess(AbstractExpression):
             self.kwargs = kwargs
 
         def associate(self, node_data: AbstractNodeData) -> List[
-            Tuple[str, Optional[AbstractExpression]]
+            Tuple[int | str, Optional[AbstractExpression]]
         ]:
             """
             Try to associate passed arguments with each natural argument in the
@@ -488,13 +538,13 @@ class FieldAccess(AbstractExpression):
             """
             args = list(enumerate(self.args, 1))
             kwargs = dict(self.kwargs)
-            result: List[Tuple[str, Optional[AbstractExpression]]] = []
+            result: List[Tuple[int | str, Optional[AbstractExpression]]] = []
             for arg_spec in node_data.natural_arguments:
                 actual: Optional[Optional[AbstractExpression]]
 
                 # Look for a keyword argument corresponding to `arg_spec`
                 arg_name = arg_spec.name.lower
-                key = arg_spec.name.lower
+                key: int | str = arg_spec.name.lower
                 try:
                     actual = kwargs.pop(arg_name)
                 except KeyError:
@@ -835,8 +885,9 @@ class FieldAccess(AbstractExpression):
             return '\n'.join(result)
 
         def _render_expr(self) -> str:
-            return (self.result_var.name
-                    if self.result_var else self.field_access_expr)
+            return (str(self.result_var.name)
+                    if self.result_var else
+                    self.field_access_expr)
 
         @property
         def subexprs(self) -> dict:
@@ -849,18 +900,23 @@ class FieldAccess(AbstractExpression):
     def __init__(self,
                  receiver: AbstractExpression,
                  field: str,
-                 arguments: Optional[FieldAccess.Arguments] = None):
+                 arguments: Optional[FieldAccess.Arguments] = None,
+                 check_call_syntax: bool = False):
         """
         :param receiver: Expression on which the field access was done.
         :param field: The name of the field that is accessed.
         :param arguments: Assuming field is a property that takes arguments,
             these are passed to it.
+        :param check_call_syntax: Whether the presence/absence of a call syntax
+            for the accessed node data must be checked (True for Lkt
+            expressions, False for DSL expressions).
         """
         super().__init__()
         self.receiver = receiver
         self.field = field
         self.arguments = arguments
         self.is_deref = False
+        self.check_call_syntax = check_call_syntax
 
         self.node_data: AbstractNodeData
 
@@ -956,6 +1012,24 @@ class FieldAccess(AbstractExpression):
         if isinstance(actual_node_data, PropertyDef):
             actual_node_data = actual_node_data.root
 
+            if self.check_call_syntax:
+                # Reject the call syntax for lazy fields, and mandate it for
+                # regular properties.
+                if actual_node_data.lazy_field:
+                    check_source_language(
+                        self.arguments is None, "cannot call a lazy field"
+                    )
+                else:
+                    check_source_language(
+                        self.arguments is not None,
+                        "call syntax is mandatory for properties",
+                    )
+        elif self.check_call_syntax:
+            # Reject the call syntax for anything that is not a property
+            check_source_language(
+                self.arguments is None, "cannot call a field"
+            )
+
         args = self.arguments or FieldAccess.Arguments([], {})
         result = self.common_construct(
             self.receiver_expr, node_data, actual_node_data, args,
@@ -1329,6 +1403,11 @@ class Match(AbstractExpression):
         """
 
     def do_prepare(self):
+        # When Lkt lowering creates this expression, there is no preparation
+        # left to do.
+        if self.matchers is not None:
+            return
+
         self.matchers = []
 
         for i, match_fn in enumerate(self.matchers_functions):
