@@ -10,6 +10,9 @@ for label, text in (
     ('simple-attr', "a'b"),
     ('char-dot', "'a'.b"),
     ('id-char', "a'b'"),
+    ('unicode-id-char', "\xe9'\U0001f642'"),
+    ('access', "access T"),
+    ('tick-access', "T'access"),
 ):
     print('== {} =='.format(label))
     u = ctx.get_from_buffer('{}.txt'.format(label), text)
@@ -18,7 +21,7 @@ for label, text in (
             print(d)
         print('--')
     for t in u.iter_tokens():
-        print(t)
+        print(ascii(str(t)))
     print('')
 
 print('main.py: Done.')
