@@ -39,5 +39,9 @@ class Example(FooNode):
         return Self.children_env.get("foo")
 
 
-build_and_run(lkt_file="expected_concrete_syntax.lkt", py_script="main.py")
+build_and_run(
+    lkt_file="expected_concrete_syntax.lkt",
+    py_script="main.py",
+    types_from_lkt=True,
+)
 print("Done")
