@@ -30,6 +30,6 @@ class Example(FooNode):
 build_and_run(
     lkt_file="expected_concrete_syntax.lkt",
     gpr_mains=["main.adb"],
-    lkt_semantic_checks=True,
+    types_from_lkt=True,
 )
 print("Done")
