@@ -30,7 +30,7 @@ class Name(FooNode):
     @langkit_property(public=True)
     def resolve():
         candidates = Var(
-            Self.node_env.get(Self).map(lambda d: d.cast(T.Definition))
+            Self.node_env.get(Self.symbol).map(lambda d: d.cast(T.Definition))
         )
         return Self.ref_var.domain(candidates).solve
 
@@ -39,5 +39,9 @@ class Name(FooNode):
         return Self.ref_var.get_value.cast(T.Definition)
 
 
-build_and_run(lkt_file='expected_concrete_syntax.lkt', py_script='main.py')
+build_and_run(
+    lkt_file='expected_concrete_syntax.lkt',
+    py_script='main.py',
+    types_from_lkt=True,
+)
 print('Done')
