@@ -31,5 +31,9 @@ class Literal(FooNode):
         return Let(lambda _=Self.b: Self.as_bare_entity)
 
 
-build_and_run(lkt_file='expected_concrete_syntax.lkt', py_script='main.py')
+build_and_run(
+    lkt_file='expected_concrete_syntax.lkt',
+    py_script='main.py',
+    types_from_lkt=True,
+)
 print('Done')
