@@ -34,5 +34,9 @@ class Example(SomeNode):
                 Predicate(SomeNode.test_prop, Self.v)).solve
 
 
-build_and_run(lkt_file='expected_concrete_syntax.lkt', py_script='main.py')
+build_and_run(
+    lkt_file='expected_concrete_syntax.lkt',
+    py_script='main.py',
+    types_from_lkt=True,
+)
 print('Done')
