@@ -41,7 +41,10 @@ class Def(FooNode):
     )
 
 
-build_and_run(lkt_file='expected_concrete_syntax.lkt', py_script='main.py',
-              lkt_semantic_checks=True)
+build_and_run(
+    lkt_file='expected_concrete_syntax.lkt',
+    py_script='main.py',
+    types_from_lkt=True,
+)
 print('')
 print('Done')
